//**********************************************************/
// Bug Fix: Webpack plugin breaks JavaScript code when require.ensure() is used (Duda Mobile)
// See https://sealights.atlassian.net/browse/SLDEV-2115
//
// Basically this is a workaround for:
// https://github.com/estools/escodegen/issues/336
//**********************************************************/
function removeWebpackComments(input) {
    //	This regex should capture block comment filled with stars, globally.
    //	Good:
    //	    /**/
    //	    /***/
    //	    /*****************/
    //	Bad:
    //	    /*/
    //      //
    //	    /***a*/
    //
    var regex = new RegExp("\/[\*]{2,}\/", "g");
    while (true) {
        //Execute the regex, each time on a different part of the input string.
        var currentMatch = regex.exec(input);
        if (!currentMatch)
            break;
        var matchIndex = currentMatch.index;
        var matchLength = currentMatch[0].length;
        var whiteSpace = createWhiteSpace(matchLength);
        //Replace the matching comment with whitespace.
        input = replaceAt(input, matchIndex, whiteSpace);
    }
    return input;
}
function createWhiteSpace(length) {
    var arr = new Array(++length);
    return arr.join(" ");
}
function replaceAt(string, index, replacement) {
    return string.substr(0, index) + replacement + string.substr(index + replacement.length);
}
function unescapeUnicode0275(input) {
    if (input && process.env.SL_UNESCAPE === '1') {
        return input.replace(/ɵ/g, '\\u0275');
    }
    return input;
}
//**********************************************************/
// Bug Fix: When instrumenting a 'React' based page, page loading breaks due to a missing space after a 'return' statement.
//
// Instead of having " return</div>" which breaks the page, we change it to
// " return </div>"
//**********************************************************/
function fixMissingSpaceAfterReturnStatement(input) {
    return input.replace(/;return</g, ";return <");
}
module.exports = {
    removeWebpackComments,
    fixMissingSpaceAfterReturnStatement,
    unescapeUnicode0275,
};
//# sourceMappingURL=instrumentation-utils.js.map