import { AgentData, BuildMappingChunkRequest, BuildMappingRequest, BuildSessionData, CreateBuildSessionIdResponse, EndExecutionRequest, GetRemoteConfigRequest, GetVersionRequest, IBuildEndData, IBuildMapEndRequest, IColoredExecutionRequest, ITestsRecommendationResponse, NodeV8CoverageMap, NodeV8RawHitsPayload, NycCoverageMap, NycRawHitsPayload, SlAgentMetadata, StartExecutionRequest, IMetricsBatch, SubmitLogsRequest, UploadReportsBody, InstrumentationMethodology, BuildMappingSubmitted } from './contracts';
import { IClockSyncResult, IExecutionResponse, IIntegrationBuildDependency } from '../contracts';
import { IEventsFile } from '../events-process/events-contracts';
import { IAgentEventRequest } from '../agent-events/agent-events-contracts';
import { IFootprintsV6File } from '../footprints-process-v6/contracts';
export interface IBackendProxy {
    getBuildSession(buildSessionId: string, callback: (err: Error, response: BuildSessionData) => void): void;
    createBuildSessionId(request: BuildSessionData, callback: (err: Error, response: CreateBuildSessionIdResponse) => void): void;
    createBuildSessionIdPromise<T extends BuildSessionData>(request: T): Promise<string>;
    getRecommendedVersion(request: GetVersionRequest): Promise<any>;
    submitBuildMapping(request: BuildMappingRequest): Promise<any>;
    checkIfBuildMappingIsSubmitted(buildSessionId: string): Promise<BuildMappingSubmitted>;
    submitPartialBuildMapping(request: BuildMappingChunkRequest, agentId: string, buildSessionId: string, index: string): Promise<any>;
    submitBuildMappingEnd(request: IBuildMapEndRequest, buildSessionId: string): Promise<any>;
    submitLogs(request: SubmitLogsRequest): Promise<void>;
    submitAgentMetrics(request: IMetricsBatch): Promise<void>;
    getRemoteConfig(request: GetRemoteConfigRequest, callback: (err: Error, body: any) => void): void;
    getRemoteConfigPromise(request: GetRemoteConfigRequest): Promise<object>;
    startExecution(request: StartExecutionRequest, callback: (err: Error, body: any) => void): void;
    startColoredExecution(request: IColoredExecutionRequest): Promise<void>;
    testExecutionV4(labId: string, async?: boolean, executionId?: string): Promise<IExecutionResponse>;
    uploadReport(request: UploadReportsBody | AgentData, callback: (err: Error, body: any) => void): void;
    externalReport(request: UploadReportsBody | AgentData, callback: (err: Error, body: any) => void): void;
    endExecution(request: EndExecutionRequest, callback: (err: Error, body: any) => void): void;
    endExecutionPromise(request: EndExecutionRequest): Promise<void>;
    submitEvents(packetToSend: IEventsFile, callback: (err: Error, body: any) => void, async: any): void;
    submitEventsPromise(packetToSend: IEventsFile): Promise<void>;
    submitBlob(body: object, buildSessionId: string, blobId: string, callback: (err: Error, body: any) => void): void;
    getBlobsAsJson<T = {
        [generatedUid: string]: string;
    }>(buildSessionId: string, blobType?: string): Promise<T[]>;
    submitBlobAsync(body: object, buildSessionId: string, blobId: string, blobType?: string): Promise<void>;
    submitAgentEvent<T>(body: IAgentEventRequest<T>): Promise<void>;
    getTestsRecommendation(buildSessionId: string, stage: string, testGroupId?: string): Promise<ITestsRecommendationResponse>;
    addOrUpdateIntegrationBuildComponents(buildSessionId: string, components: IIntegrationBuildDependency[], agentId: string): Promise<any>;
    deleteIntegrationBuildComponents(buildSessionId: string, components: IIntegrationBuildDependency[], agentId: string): Promise<any>;
    buildEnd(data: IBuildEndData): Promise<void>;
    submitFootprintsV6(footprintsPacket: IFootprintsV6File, executionBsid: string, testStage: string, buildSessionId: string): Promise<void>;
    getBuildSessionData(buildSessionId: string): Promise<BuildSessionData>;
    getRecommendedAgent(configuration?: any): Promise<{}>;
    getBuildSessionDataFromLabId(labid: string): Promise<BuildSessionData>;
    updateMetadata(metadata: Partial<SlAgentMetadata>): void;
    submitNycCoverageMap(buildSessionId: string, map: NycCoverageMap): Promise<void>;
    submitNodeV8CoverageMap(buildSessionId: string, map: NodeV8CoverageMap): Promise<void>;
    submitRawCoverageMapEnd(buildSessionId: string): Promise<void>;
    submitNycRawCoverageHits(executionBsid: string, buildSessionId: string, testStage: string, hits: NycRawHitsPayload): Promise<void>;
    submitNodeV8RawCoverageHits(executionBsid: string, buildSessionId: string, testStage: string, hits: NodeV8RawHitsPayload): Promise<void>;
    submitFootprintsToCollector(footprintsPacket: IFootprintsV6File, buildSessionId: string): Promise<void>;
    getSyncedTime(currentTime: number): Promise<IClockSyncResult>;
    getInstrumentationMethodology(buildSessionId: string): Promise<{
        methodology: InstrumentationMethodology;
    }>;
}
